dnsbase
Copyright(c) Viktor Dukhovni 2026
LicenseBSD-3-Clause
Maintainerietf-dane@dukhovni.org
Stabilityunstable
Safe HaskellNone
LanguageGHC2024

Net.DNSBase.RRTYPE

Description

The 16-bit TYPE field of a DNS resource record, along with the type-level Nat synonyms (N_a, N_ns, N_aaaa, ...) that index the shared-codec and opaque datatypes (X_domain, X_svcb, X_ds, X_key, X_sig) and select among the RR types that share a single underlying representation. See the IANA Resource Record (RR) TYPEs registry for the full list of codepoints.

Synopsis

DNS Resource Record type numbers

newtype RRTYPE Source #

DNS Resource Record type numbers. The Presentable instance displays the standard presentation form of the type name for known types, or else TYPEnnnnn for a generic type number nnnnn.

Constructors

RRTYPE Word16 

Bundled Patterns

pattern A :: RRTYPE

IP4 address.

pattern A6 :: RRTYPE

A6.

pattern AAAA :: RRTYPE

IP6 Address.

pattern AFSDB :: RRTYPE

AFS Data Base location,

pattern AMTRELAY :: RRTYPE

Automatic Multicast Tunneling Relay (RFC8777)

pattern ANY :: RRTYPE

A request for all records the server/cache has available Reserved special-purpose type.

pattern APL :: RRTYPE

Address prefix list. Not implemented.

pattern ATMA :: RRTYPE

ATM Address Not implemented.

                                 1  1  1  1  1  1
   0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
|          FORMAT       |                       |
+--+--+--+--+--+--+--+--+                       |
/                    ADDRESS                    /
|                                               |
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
  • FORMAT: One octet that indicates the format of ADDRESS. The two possible values for FORMAT are value 0 indicating ATM End System Address (AESA) format and value 1 indicating E.164 format.
  • ADDRESS: Variable length string of octets containing the ATM address of the node to which this RR pertains.
pattern AXFR :: RRTYPE

Zone transfer (RFC5936) Reserved special-purpose type.

pattern BRID :: RRTYPE

Broadcast Remote Identification Not implemented.

pattern CAA :: RRTYPE

Certification Authority Authorization (RFC6844)

pattern CDNSKEY :: RRTYPE

Child DNSKEY. DNSKEY(s) the Child wants reflected in DS.

pattern CDS :: RRTYPE

Child DS. The CDS RRSet expresses what the Child would like the DS RRSet to look like.

pattern CERT :: RRTYPE

Cerificate Not implemented.

pattern CLA :: RRTYPE

BP Convergence Layer Adapter draft-johnson-dns-ipn-cla Not implemented.

pattern CNAME :: RRTYPE

Canonical name for an alias.

pattern CSYNC :: RRTYPE

Child-To-Parent Synchronization

pattern DHCID :: RRTYPE

DHCP Information Not implemented.

pattern DNAME :: RRTYPE

Name redirection.

pattern DNSKEY :: RRTYPE

DNSKEY See RFC4034 for protocol details.

pattern DS :: RRTYPE

Delegation Signer See RFC4034 for protocol details.

pattern DSYNC :: RRTYPE

Generalized DNS Notifications

pattern EID :: RRTYPE

Endpoint Identifier. Not implemented.

                                 1  1  1  1  1  1
   0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
/                       RDATA                   /
/                                               /
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
  • RDATA: a string of octets containing the Endpoint Identifier. The value is the binary encoding of the Identifier, meaningful only to the system utilizing it.
pattern GPOS :: RRTYPE

Geographical Position.

pattern HHIT :: RRTYPE

Hierarchical Host Identity Tag Not implemented.

pattern HINFO :: RRTYPE

Host information.

pattern HIP :: RRTYPE

Host Identity Protocol. Not implemented.

pattern HTTPS :: RRTYPE

SVCB-compatible type for use with HTTP

pattern IPN :: RRTYPE

BP Node Number draft-johnson-dns-ipn-cla Not implemented.

pattern IPSECKEY :: RRTYPE

IPSEC KEY.

pattern ISDN :: RRTYPE

ISDN address.

pattern IXFR :: RRTYPE

Incremental transfer (RFC1995) Reserved special-purpose type.

pattern KEY :: RRTYPE

Security Key.

pattern KX :: RRTYPE

Key Exchanger

pattern L32 :: RRTYPE

ILNPv4 32-bit locator

pattern L64 :: RRTYPE

ILNPv6 64-bit locator

pattern LOC :: RRTYPE

Location Information. Not implemented:

pattern LP :: RRTYPE

ILNP Locator Pointer

pattern MAILA :: RRTYPE

A request for mail agent RRs (Obsolete - see MX) Reserved special-purpose type.

pattern MAILB :: RRTYPE

A request for mailbox-related records (MB, MG or MR) Reserved special-purpose type.

pattern MB :: RRTYPE

Mailbox domain name (EXPERIMENTAL).

pattern MD :: RRTYPE

Mail destination (Obsolete - use MX).

pattern MF :: RRTYPE

Mail forwarder (Obsolete - use MX).

pattern MG :: RRTYPE

Mail group member (EXPERIMENTAL).

pattern MINFO :: RRTYPE

[mailbox information (EXPERIMENTAL)(https:/tools.ietf.orghtml/rfc1035#section-3.2.2).

pattern MR :: RRTYPE

Mail rename domain name (EXPERIMENTAL).

pattern MX :: RRTYPE

Mail exchange.

pattern NAPTR :: RRTYPE

Naming Authority Pointer

pattern NID :: RRTYPE

Node Identifier

pattern NIMLOC :: RRTYPE

Nimrod Locator. Not implemented

                                 1  1  1  1  1  1
   0  1  2  3  4  5  6  7  8  9  0  1  2  3  4  5
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
/                       RDATA                   /
/                                               /
+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
  • RDATA: a variable length string of octets containing the Nimrod Locator. The value is the binary encoding of the Locator specified in the Nimrod protocol[[[ref to be supplied]]].
pattern NINFO :: RRTYPE

Zone status information Not implemented.

pattern NS :: RRTYPE

Authoritative name server.

pattern NSAP :: RRTYPE

NSAP style address. DEPRECATED

pattern NSAPPTR :: RRTYPE

NSAP style PTR. DEPRECATED

pattern NSEC :: RRTYPE

NSEC See RFC4034 for protocol details.

pattern NSEC3 :: RRTYPE

Hashed authenticated denial of existence

pattern NSEC3PARAM :: RRTYPE

NSEC3PARAM.

pattern NULL :: RRTYPE

Null RR (EXPERIMENTAL).

pattern NXNAME :: RRTYPE

NXDOMAIN indicator for Compact Denial of Existence Reserved sentinel type.

pattern NXT :: RRTYPE

Next Domain.

pattern OPENPGPKEY :: RRTYPE

OPENPGP Key.

pattern OPT :: RRTYPE

DNS extension options.

pattern PTR :: RRTYPE

Domain name pointer.

pattern PX :: RRTYPE

X.400 mail mapping information.

pattern RESINFO :: RRTYPE

DNS Resolver Information RFC9606, section 8.1 Not implemented.

pattern RKEY :: RRTYPE

RKEY Not implemented

pattern RP :: RRTYPE

Responsible Person

pattern RRSIG :: RRTYPE

RRSIG See RFC4034 for protocol details.

pattern RT :: RRTYPE

Route Through.

pattern SIG :: RRTYPE

Security Signature.

pattern SINK :: RRTYPE

SINK. Not implemented.

pattern SMIMEA :: RRTYPE

DANE SMIMEA.

pattern SOA :: RRTYPE

Start of a zone of authority.

pattern SRV :: RRTYPE

Server Selection.

pattern SSHFP :: RRTYPE

SSH Key fingerprint.

pattern SVCB :: RRTYPE

General Purpose Service Binding

pattern TALINK :: RRTYPE

Trust Anchor LINK Not implemented.

pattern TLSA :: RRTYPE

DANE TLSA.

pattern TXT :: RRTYPE

Text strings.

pattern WALLET :: RRTYPE

Public wallet address Registration template Not implemented.

pattern WKS :: RRTYPE

Well known service description.

pattern X25 :: RRTYPE

X.25 PSDN address.

pattern ZONEMD :: RRTYPE

Zone Message Digest

Instances

Instances details
Presentable RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Bounded RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Enum RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Num RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Read RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Integral RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Real RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Show RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Eq RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Methods

(==) :: RRTYPE -> RRTYPE -> Bool #

(/=) :: RRTYPE -> RRTYPE -> Bool #

Ord RRTYPE Source # 
Instance details

Defined in Net.DNSBase.Internal.RRTYPE

Corresponding type-level Naturals

type N_a = 1 Source #

type N_ns = 2 Source #

type N_md = 3 Source #

type N_mf = 4 Source #

type N_cname = 5 Source #

type N_soa = 6 Source #

type N_mb = 7 Source #

type N_mg = 8 Source #

type N_mr = 9 Source #

type N_null = 10 Source #

type N_wks = 11 Source #

type N_ptr = 12 Source #

type N_hinfo = 13 Source #

type N_minfo = 14 Source #

type N_mx = 15 Source #

type N_txt = 16 Source #

type N_rp = 17 Source #

type N_afsdb = 18 Source #

type N_x25 = 19 Source #

type N_isdn = 20 Source #

type N_rt = 21 Source #

type N_nsap = 22 Source #

type N_nsapptr = 23 Source #

type N_sig = 24 Source #

type N_key = 25 Source #

type N_px = 26 Source #

type N_gpos = 27 Source #

type N_aaaa = 28 Source #

type N_loc = 29 Source #

type N_nxt = 30 Source #

type N_eid = 31 Source #

type N_nimloc = 32 Source #

type N_srv = 33 Source #

type N_atma = 34 Source #

type N_naptr = 35 Source #

type N_kx = 36 Source #

type N_cert = 37 Source #

type N_a6 = 38 Source #

type N_dname = 39 Source #

type N_sink = 40 Source #

type N_opt = 41 Source #

type N_apl = 42 Source #

type N_ds = 43 Source #

type N_sshfp = 44 Source #

type N_ipseckey = 45 Source #

type N_rrsig = 46 Source #

type N_nsec = 47 Source #

type N_dnskey = 48 Source #

type N_dhcid = 49 Source #

type N_nsec3 = 50 Source #

type N_tlsa = 52 Source #

type N_smimea = 53 Source #

type N_hip = 55 Source #

type N_ninfo = 56 Source #

type N_rkey = 57 Source #

type N_talink = 58 Source #

type N_cds = 59 Source #

type N_cdnskey = 60 Source #

type N_csync = 62 Source #

type N_zonemd = 63 Source #

type N_svcb = 64 Source #

type N_https = 65 Source #

type N_dsync = 66 Source #

type N_hhit = 67 Source #

type N_brid = 68 Source #

type N_nid = 104 Source #

type N_l32 = 105 Source #

type N_l64 = 106 Source #

type N_lp = 107 Source #

type N_nxname = 128 Source #

type N_ixfr = 251 Source #

type N_axfr = 252 Source #

type N_mailb = 253 Source #

type N_maila = 254 Source #

type N_any = 255 Source #

type N_caa = 257 Source #

type N_amtrelay = 260 Source #

type N_resinfo = 261 Source #

type N_wallet = 262 Source #

type N_cla = 263 Source #

type N_ipn = 264 Source #