| Copyright | (c) Viktor Dukhovni 2026 |
|---|---|
| License | BSD-3-Clause |
| Maintainer | ietf-dane@dukhovni.org |
| Stability | unstable |
| Safe Haskell | None |
| Language | GHC2024 |
Net.DNSBase.Bytes
Description
Three identical ShortByteString wrappers that differ only in
their Presentable instance: Bytes16
renders as hex, Bytes32 as base32, Bytes64 as base64. Used
inside RR data types to tag a field with the encoding the
zone-file syntax expects, so that a single
present call produces the conventional
representation without each call site having to pick the encoder.
Short ByteStrings elements that are presented encoded
ByteStrings with a hexadecimal presentation form
Constructors
| Bytes16 | |
Fields | |
Instances
| Presentable Bytes16 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods present :: Bytes16 -> Builder -> Builder Source # presentLazy :: Bytes16 -> ByteString -> ByteString Source # | |
| Monoid Bytes16 Source # | |
| Semigroup Bytes16 Source # | |
| IsString Bytes16 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods fromString :: String -> Bytes16 # | |
| Show Bytes16 Source # | |
| Eq Bytes16 Source # | |
| Ord Bytes16 Source # | |
Defined in Net.DNSBase.Internal.Bytes | |
ByteStrings with a base32 presentation form
Constructors
| Bytes32 | |
Fields | |
Instances
| Presentable Bytes32 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods present :: Bytes32 -> Builder -> Builder Source # presentLazy :: Bytes32 -> ByteString -> ByteString Source # | |
| Monoid Bytes32 Source # | |
| Semigroup Bytes32 Source # | |
| IsString Bytes32 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods fromString :: String -> Bytes32 # | |
| Show Bytes32 Source # | |
| Eq Bytes32 Source # | |
| Ord Bytes32 Source # | |
Defined in Net.DNSBase.Internal.Bytes | |
ByteStrings with a base64 presentation form
Constructors
| Bytes64 | |
Fields | |
Instances
| Presentable Bytes64 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods present :: Bytes64 -> Builder -> Builder Source # presentLazy :: Bytes64 -> ByteString -> ByteString Source # | |
| Monoid Bytes64 Source # | |
| Semigroup Bytes64 Source # | |
| IsString Bytes64 Source # | |
Defined in Net.DNSBase.Internal.Bytes Methods fromString :: String -> Bytes64 # | |
| Show Bytes64 Source # | |
| Eq Bytes64 Source # | |
| Ord Bytes64 Source # | |
Defined in Net.DNSBase.Internal.Bytes | |