| Copyright | (c) Viktor Dukhovni 2026 |
|---|---|
| License | BSD-3-Clause |
| Maintainer | ietf-dane@dukhovni.org |
| Stability | unstable |
| Safe Haskell | None |
| Language | GHC2024 |
Net.DNSBase.RRTYPE
Description
The 16-bit TYPE field of a DNS resource record, along with
the type-level Nat synonyms (N_a, N_ns, N_aaaa, ...)
that index the shared-codec and opaque datatypes
(X_domain,
X_svcb,
X_ds,
X_key,
X_sig)
and select among the RR types that share a single underlying
representation. See the
IANA Resource Record (RR) TYPEs registry
for the full list of codepoints.
Synopsis
- newtype RRTYPE where
- RRTYPE Word16
- pattern A :: RRTYPE
- pattern A6 :: RRTYPE
- pattern AAAA :: RRTYPE
- pattern AFSDB :: RRTYPE
- pattern AMTRELAY :: RRTYPE
- pattern ANY :: RRTYPE
- pattern APL :: RRTYPE
- pattern ATMA :: RRTYPE
- pattern AXFR :: RRTYPE
- pattern BRID :: RRTYPE
- pattern CAA :: RRTYPE
- pattern CDNSKEY :: RRTYPE
- pattern CDS :: RRTYPE
- pattern CERT :: RRTYPE
- pattern CLA :: RRTYPE
- pattern CNAME :: RRTYPE
- pattern CSYNC :: RRTYPE
- pattern DHCID :: RRTYPE
- pattern DNAME :: RRTYPE
- pattern DNSKEY :: RRTYPE
- pattern DS :: RRTYPE
- pattern DSYNC :: RRTYPE
- pattern EID :: RRTYPE
- pattern GPOS :: RRTYPE
- pattern HHIT :: RRTYPE
- pattern HINFO :: RRTYPE
- pattern HIP :: RRTYPE
- pattern HTTPS :: RRTYPE
- pattern IPN :: RRTYPE
- pattern IPSECKEY :: RRTYPE
- pattern ISDN :: RRTYPE
- pattern IXFR :: RRTYPE
- pattern KEY :: RRTYPE
- pattern KX :: RRTYPE
- pattern L32 :: RRTYPE
- pattern L64 :: RRTYPE
- pattern LOC :: RRTYPE
- pattern LP :: RRTYPE
- pattern MAILA :: RRTYPE
- pattern MAILB :: RRTYPE
- pattern MB :: RRTYPE
- pattern MD :: RRTYPE
- pattern MF :: RRTYPE
- pattern MG :: RRTYPE
- pattern MINFO :: RRTYPE
- pattern MR :: RRTYPE
- pattern MX :: RRTYPE
- pattern NAPTR :: RRTYPE
- pattern NID :: RRTYPE
- pattern NIMLOC :: RRTYPE
- pattern NINFO :: RRTYPE
- pattern NS :: RRTYPE
- pattern NSAP :: RRTYPE
- pattern NSAPPTR :: RRTYPE
- pattern NSEC :: RRTYPE
- pattern NSEC3 :: RRTYPE
- pattern NSEC3PARAM :: RRTYPE
- pattern NULL :: RRTYPE
- pattern NXNAME :: RRTYPE
- pattern NXT :: RRTYPE
- pattern OPENPGPKEY :: RRTYPE
- pattern OPT :: RRTYPE
- pattern PTR :: RRTYPE
- pattern PX :: RRTYPE
- pattern RESINFO :: RRTYPE
- pattern RKEY :: RRTYPE
- pattern RP :: RRTYPE
- pattern RRSIG :: RRTYPE
- pattern RT :: RRTYPE
- pattern SIG :: RRTYPE
- pattern SINK :: RRTYPE
- pattern SMIMEA :: RRTYPE
- pattern SOA :: RRTYPE
- pattern SRV :: RRTYPE
- pattern SSHFP :: RRTYPE
- pattern SVCB :: RRTYPE
- pattern TALINK :: RRTYPE
- pattern TLSA :: RRTYPE
- pattern TXT :: RRTYPE
- pattern WALLET :: RRTYPE
- pattern WKS :: RRTYPE
- pattern X25 :: RRTYPE
- pattern ZONEMD :: RRTYPE
- type N_a = 1
- type N_ns = 2
- type N_md = 3
- type N_mf = 4
- type N_cname = 5
- type N_soa = 6
- type N_mb = 7
- type N_mg = 8
- type N_mr = 9
- type N_null = 10
- type N_wks = 11
- type N_ptr = 12
- type N_hinfo = 13
- type N_minfo = 14
- type N_mx = 15
- type N_txt = 16
- type N_rp = 17
- type N_afsdb = 18
- type N_x25 = 19
- type N_isdn = 20
- type N_rt = 21
- type N_nsap = 22
- type N_nsapptr = 23
- type N_sig = 24
- type N_key = 25
- type N_px = 26
- type N_gpos = 27
- type N_aaaa = 28
- type N_loc = 29
- type N_nxt = 30
- type N_eid = 31
- type N_nimloc = 32
- type N_srv = 33
- type N_atma = 34
- type N_naptr = 35
- type N_kx = 36
- type N_cert = 37
- type N_a6 = 38
- type N_dname = 39
- type N_sink = 40
- type N_opt = 41
- type N_apl = 42
- type N_ds = 43
- type N_sshfp = 44
- type N_ipseckey = 45
- type N_rrsig = 46
- type N_nsec = 47
- type N_dnskey = 48
- type N_dhcid = 49
- type N_nsec3 = 50
- type N_nsec3param = 51
- type N_tlsa = 52
- type N_smimea = 53
- type N_hip = 55
- type N_ninfo = 56
- type N_rkey = 57
- type N_talink = 58
- type N_cds = 59
- type N_cdnskey = 60
- type N_openpgpkey = 61
- type N_csync = 62
- type N_zonemd = 63
- type N_svcb = 64
- type N_https = 65
- type N_dsync = 66
- type N_hhit = 67
- type N_brid = 68
- type N_nid = 104
- type N_l32 = 105
- type N_l64 = 106
- type N_lp = 107
- type N_nxname = 128
- type N_ixfr = 251
- type N_axfr = 252
- type N_mailb = 253
- type N_maila = 254
- type N_any = 255
- type N_caa = 257
- type N_amtrelay = 260
- type N_resinfo = 261
- type N_wallet = 262
- type N_cla = 263
- type N_ipn = 264
DNS Resource Record type numbers
DNS Resource Record type numbers. The Presentable instance
displays the standard presentation form of the type name for
known types, or else TYPEnnnnn for a generic type number
nnnnn.
Bundled Patterns
| pattern A :: RRTYPE | |
| pattern A6 :: RRTYPE | A6. |
| pattern AAAA :: RRTYPE | |
| pattern AFSDB :: RRTYPE | |
| pattern AMTRELAY :: RRTYPE | Automatic Multicast Tunneling Relay (RFC8777) |
| pattern ANY :: RRTYPE | A request for all records the server/cache has available Reserved special-purpose type. |
| pattern APL :: RRTYPE | Address prefix list. Not implemented. |
| pattern ATMA :: RRTYPE | ATM Address Not implemented. 1 1 1 1 1 1 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+ | FORMAT | | +--+--+--+--+--+--+--+--+ | / ADDRESS / | | +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
|
| pattern AXFR :: RRTYPE | Zone transfer (RFC5936) Reserved special-purpose type. |
| pattern BRID :: RRTYPE | Broadcast Remote Identification Not implemented. |
| pattern CAA :: RRTYPE | Certification Authority Authorization (RFC6844) |
| pattern CDNSKEY :: RRTYPE | Child DNSKEY. DNSKEY(s) the Child wants reflected in DS. |
| pattern CDS :: RRTYPE | Child DS. The CDS RRSet expresses what the Child would like the DS RRSet to look like. |
| pattern CERT :: RRTYPE | Cerificate Not implemented. |
| pattern CLA :: RRTYPE | BP Convergence Layer Adapter draft-johnson-dns-ipn-cla Not implemented. |
| pattern CNAME :: RRTYPE | |
| pattern CSYNC :: RRTYPE | |
| pattern DHCID :: RRTYPE | DHCP Information Not implemented. |
| pattern DNAME :: RRTYPE | |
| pattern DNSKEY :: RRTYPE | |
| pattern DS :: RRTYPE | Delegation Signer See RFC4034 for protocol details. |
| pattern DSYNC :: RRTYPE | |
| pattern EID :: RRTYPE | Endpoint Identifier. Not implemented. 1 1 1 1 1 1 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+ / RDATA / / / +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
|
| pattern GPOS :: RRTYPE | |
| pattern HHIT :: RRTYPE | Hierarchical Host Identity Tag Not implemented. |
| pattern HINFO :: RRTYPE | |
| pattern HIP :: RRTYPE | Host Identity Protocol. Not implemented. |
| pattern HTTPS :: RRTYPE | |
| pattern IPN :: RRTYPE | BP Node Number draft-johnson-dns-ipn-cla Not implemented. |
| pattern IPSECKEY :: RRTYPE | |
| pattern ISDN :: RRTYPE | |
| pattern IXFR :: RRTYPE | Incremental transfer (RFC1995) Reserved special-purpose type. |
| pattern KEY :: RRTYPE | |
| pattern KX :: RRTYPE | |
| pattern L32 :: RRTYPE | |
| pattern L64 :: RRTYPE | |
| pattern LOC :: RRTYPE | Location Information. Not implemented: |
| pattern LP :: RRTYPE | |
| pattern MAILA :: RRTYPE | A request for mail agent RRs (Obsolete - see MX) Reserved special-purpose type. |
| pattern MAILB :: RRTYPE | A request for mailbox-related records (MB, MG or MR) Reserved special-purpose type. |
| pattern MB :: RRTYPE | |
| pattern MD :: RRTYPE | |
| pattern MF :: RRTYPE | |
| pattern MG :: RRTYPE | |
| pattern MINFO :: RRTYPE | [mailbox information (EXPERIMENTAL)(https:/tools.ietf.orghtml/rfc1035#section-3.2.2). |
| pattern MR :: RRTYPE | |
| pattern MX :: RRTYPE | |
| pattern NAPTR :: RRTYPE | |
| pattern NID :: RRTYPE | |
| pattern NIMLOC :: RRTYPE | Nimrod Locator. Not implemented 1 1 1 1 1 1 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+ / RDATA / / / +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
|
| pattern NINFO :: RRTYPE | Zone status information Not implemented. |
| pattern NS :: RRTYPE | |
| pattern NSAP :: RRTYPE | |
| pattern NSAPPTR :: RRTYPE | |
| pattern NSEC :: RRTYPE | |
| pattern NSEC3 :: RRTYPE | |
| pattern NSEC3PARAM :: RRTYPE | |
| pattern NULL :: RRTYPE | |
| pattern NXNAME :: RRTYPE | NXDOMAIN indicator for Compact Denial of Existence Reserved sentinel type. |
| pattern NXT :: RRTYPE | |
| pattern OPENPGPKEY :: RRTYPE | |
| pattern OPT :: RRTYPE | |
| pattern PTR :: RRTYPE | |
| pattern PX :: RRTYPE | |
| pattern RESINFO :: RRTYPE | DNS Resolver Information RFC9606, section 8.1 Not implemented. |
| pattern RKEY :: RRTYPE | RKEY Not implemented |
| pattern RP :: RRTYPE | |
| pattern RRSIG :: RRTYPE | |
| pattern RT :: RRTYPE | |
| pattern SIG :: RRTYPE | |
| pattern SINK :: RRTYPE | SINK. Not implemented. |
| pattern SMIMEA :: RRTYPE | |
| pattern SOA :: RRTYPE | |
| pattern SRV :: RRTYPE | |
| pattern SSHFP :: RRTYPE | |
| pattern SVCB :: RRTYPE | |
| pattern TALINK :: RRTYPE | Trust Anchor LINK Not implemented. |
| pattern TLSA :: RRTYPE | |
| pattern TXT :: RRTYPE | |
| pattern WALLET :: RRTYPE | Public wallet address Registration template Not implemented. |
| pattern WKS :: RRTYPE | |
| pattern X25 :: RRTYPE | |
| pattern ZONEMD :: RRTYPE |
Instances
| Presentable RRTYPE Source # | |
Defined in Net.DNSBase.Internal.RRTYPE Methods present :: RRTYPE -> Builder -> Builder Source # presentLazy :: RRTYPE -> ByteString -> ByteString Source # | |
| Bounded RRTYPE Source # | |
| Enum RRTYPE Source # | |
Defined in Net.DNSBase.Internal.RRTYPE | |
| Num RRTYPE Source # | |
| Read RRTYPE Source # | |
| Integral RRTYPE Source # | |
Defined in Net.DNSBase.Internal.RRTYPE | |
| Real RRTYPE Source # | |
Defined in Net.DNSBase.Internal.RRTYPE Methods toRational :: RRTYPE -> Rational # | |
| Show RRTYPE Source # | |
| Eq RRTYPE Source # | |
| Ord RRTYPE Source # | |
Corresponding type-level Naturals
type N_ipseckey = 45 Source #
type N_nsec3param = 51 Source #
type N_openpgpkey = 61 Source #
type N_amtrelay = 260 Source #